Attribute

Trait Attribute 

pub trait Attribute<V: SynVersion>: AttributeName + TryFromMeta<V, Metadata = V::Attribute> {
    // Provided method
    fn from_attrs(
        location: Span,
        attrs: Vec<V::Attribute>,
    ) -> Result<Self, Vec<V::Error>> { ... }
}
Represents a struct that can be deserialized from Syn attributes.

Provided Methods

fn from_attrs( location: Span, attrs: Vec<V::Attribute>, ) -> Result<Self, Vec<V::Error>>

Creates a deserialized attribute from a list of Syn attributes.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl<V: SynVersion, T: Attribute<V>> Attribute<V> for Option<T>
where Self: TryFromMeta<V, Metadata = V::Attribute>,

Implementors